@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
 # This file is part of CairoSVG
-# Copyright © 2010-2012 Kozea
+# Copyright © 2010-2018 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -22,32 +21,31 @@ Helpers related to SVG conditional processing.
 
 import locale
 
-
-ROOT = "http://www.w3.org/TR/SVG11/feature"
-LOCALE = locale.getdefaultlocale()[0] or ""
-SUPPORTED_FEATURES = set(
-    ROOT + "#" + feature for feature in [
-        "SVG",
-        "SVG-static",
-        "CoreAttribute",
-        "Structure",
-        "BasicStructure",
-        "ConditionalProcessing",
-        "Image",
-        "Style",
-        "ViewportAttribute",
-        "Shape",
-        "BasicText",
-        "BasicPaintAttribute",
-        "OpacityAttribute",
-        "BasicGraphicsAttribute",
-        "Marker",
-        "Gradient",
-        "Pattern",
-        "Clip",
-        "BasicClip",
-        "Mask"
-    ])
+ROOT = 'http://www.w3.org/TR/SVG11/feature'
+LOCALE = locale.getdefaultlocale()[0] or ''
+SUPPORTED_FEATURES = frozenset((
+    ROOT + '#' + feature for feature in (
+        'SVG',
+        'SVG-static',
+        'CoreAttribute',
+        'Structure',
+        'BasicStructure',
+        'ConditionalProcessing',
+        'Image',
+        'Style',
+        'ViewportAttribute',
+        'Shape',
+        'BasicText',
+        'BasicPaintAttribute',
+        'OpacityAttribute',
+        'BasicGraphicsAttribute',
+        'Marker',
+        'Gradient',
+        'Pattern',
+        'Clip',
+        'BasicClip',
+        'Mask'
+    )))
 
 
 def has_features(features):
@@ -57,7 +55,7 @@ def has_features(features):
 
 def support_languages(languages):
     """Check whether one of ``languages`` is part of the user locales."""
-    for language in languages.split(","):
+    for language in languages.split(','):
         language = language.strip()
         if language and LOCALE.startswith(language):
             return True
@@ -66,10 +64,12 @@ def support_languages(languages):
 
 def match_features(node):
     """Check the node match the conditional processing attributes."""
-    if "requiredExtensions" in node.attrib:
+    features = node.attrib.get('requiredFeatures')
+    languages = node.attrib.get('systemLanguage')
+    if 'requiredExtensions' in node.attrib:
         return False
-    if not has_features(node.attrib.get("requiredFeatures", ROOT + "#SVG")):
+    if features is not None and not has_features(features):
         return False
-    if not support_languages(node.attrib.get("systemLanguage", LOCALE)):
+    if languages is not None and not support_languages(languages):
         return False
     return True
